@@ -5,6 +5,7 @@ Tools for generating forms based on Peewee models
 
 from collections import namedtuple
 from collections import OrderedDict
+from wtforms import __version__ as wtforms_version
 from wtforms import Form
 from wtforms import fields as f
 from wtforms import validators
@@ -54,7 +55,10 @@ class ValueRequired(object):
     truly blank values. See the implementation of DataRequired and
     InputRequired -- this class sits somewhere in the middle of them.
     """
-    field_flags = ('required',)
+    if wtforms_version < '3.1.0':
+        field_flags = ('required',)
+    else:
+        field_flags = {'required': True}
 
     def __init__(self, message=None):
         self.message = message
